@@ -1,3 +1,6 @@
+# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
+
 from dataclasses import dataclass
 from datetime import datetime, timedelta
 from typing import ClassVar, Optional
@@ -5,12 +8,13 @@ from typing import ClassVar, Optional
 
 @dataclass(frozen=True)
 class TimingWindow:
-    """
-    Representation of timing windows in the mini-model.
+    """Representation of timing windows in the mini-model.
 
-    For infinite duration, set duration to timedelta.max.
-    For repeat, -1 means forever repeating, 0 means non-repeating.
-    For period, None should be used if repeat < 1.
+    Attributes:
+        start (datetime): When a timing window begins.
+        duration (timedelta): For infinite duration, set duration to timedelta.max.
+        repeat (int):  -1 means forever repeating, 0 means non-repeating.
+        period (timedelta, optional): None should be used if repeat < 1.
     """
     start: datetime
     duration: timedelta
