@@ -1,4 +1,7 @@
-from enum import auto, IntEnum
+# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
+
+from enum import IntEnum, auto
 
 
 class TooType(IntEnum):
@@ -12,6 +15,12 @@ class TooType(IntEnum):
     but not INTERRUPT ones.
 
     The values and ordering on them should NOT be changed as this will break functionality.
+
+    Members:
+        - STANDARD
+        - RAPID
+        - INTERRUPT
+
     """
     STANDARD = auto()
     RAPID = auto()
